@@ -1255,6 +1255,15 @@ _purifyQuotedString(NSMutableString *quotedString) {
             [parse setObject:used forKey:@"usedSpace"];
             [parse setObject:max  forKey:@"maxQuota"];
           }
+          else if ([key isEqualToString:@"message"]) {
+            NSString *used, *max;
+
+            used = _parseUntil(self, ' ');
+            max  = _parseUntil(self, ')');
+
+            [parse setObject:used forKey:@"messagesCount"];
+            [parse setObject:max  forKey:@"maxMessages"];
+          }
           else {
             NSString *v;
 
@@ -1724,6 +1733,8 @@ _purifyQuotedString(NSMutableString *quotedString) {
     env->subject = [tmp isNotNull] 
       ? [[self _decodeQP:tmp headerField:@"subject"] copy]
       : nil;
+    if (![env->subject isKindOfClass: [NSString class]])
+      env->subject = [[NSString alloc] initWithData: env->subject encoding: NSUTF8StringEncoding];
     [self _consumeOptionalSpace];
   }
   else {
@@ -2265,7 +2276,7 @@ static NSDictionary *_parseSingleBody(NGImap4ResponseParser *self,
     [dict setObject:_parseBodyString(self, YES) forKey:@"lines"];
   }
   else if ([type isEqualToString:@"message"]
-	   && [subtype isEqualToString:@"rfc822"]) {
+	   && ([subtype isEqualToString:@"rfc822"] || [subtype isEqualToString:@"global"])) {
     if (_la(self, 0) != ')') {
       _consumeIfMatch(self, ' ');
       _consumeIfMatch(self, '(');
